%%
%% This is file `overpic-xetex-bidi.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% bidi.dtx  (with options: `table,overpic-xetex-bidi.def')
%% 
%%   __________________________________________________
%%   Vafa Khalighi
%% 
%%   Copyright (c) 2007--2026  Vafa Khalighi
%%   Copyright (c) 2018--2020 bidi-tex GitHub Organization
%% 
%%   It may be distributed and/or modified under the LaTeX Project Public License,
%%   version 1.3c or higher (your choice). The latest version of
%%   this license is at: http://www.latex-project.org/lppl.txt
%% 
%%   This work is “author-maintained” (as per LPPL maintenance status)
%%   by Vafa Khalighi.
%% 
%% 

%% \CheckSum{54343}
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\ProvidesFile{overpic-xetex-bidi.def}[2026/01/08 v0.2 bidi adaptations for overpic package for XeTeX engine]
\bidi@patchcmd\OVP@picture{%
    \put(0,0){\makebox(0,0)[bl]{\usebox\OVP@box}}%
    \ifOVP@grid
      \put(0,0){\normalfont\fontsize\@viipt\@viiipt\selectfont
        \grid(\@tempcnta,\@tempcntb)(\count@,\count@)[0,0]}%
    \fi
}{%
    \if@RTL
    \else
      \put(0,0){\makebox(0,0)[bl]{\usebox\OVP@box}}%
      \ifOVP@grid
        \put(0,0){\normalfont\fontsize\@viipt\@viiipt\selectfont
          \grid(\@tempcnta,\@tempcntb)(\count@,\count@)[0,0]}%
      \fi
    \fi
}{}{\bidi@warningnoline{Oops! patching `\string\OVP@picture' failed}}

\newcommand*\bidi@OVP@picture@RTL{%
  \if@RTL
    \ifOVP@grid
      \put(0,0){\normalfont\fontsize\@viipt\@viiipt\selectfont
        \grid(\@tempcnta,\@tempcntb)(\count@,\count@)[0,0]}%
    \fi
    \put(0,0){\makebox(0,0)[bl]{\usebox\OVP@box}}%
  \fi
}

\bidi@AtEndEnvironment{overpic}{\bidi@OVP@picture@RTL}
\bidi@AtEndEnvironment{Overpic}{\bidi@OVP@picture@RTL}
\endinput
%%
%% End of file `overpic-xetex-bidi.def'.
